Crate google_geo_type

Crate google_geo_type 

Google Cloud Client Libraries for Rust - Common Geo Types

This crate defines types and functions used by one or more Google Cloud services. Most applications will use the structs defined in the model module.

Modules

model
The messages and enums that are part of this client library.