Viewport

Struct Viewport 

#[non_exhaustive]
pub struct Viewport { pub low: Option<LatLng>, pub high: Option<LatLng>, /* private fields */ }
A latitude-longitude viewport, represented as two diagonally opposite low and high points. A viewport is considered a closed region, i.e. it includes its boundary. The latitude bounds must range between -90 to 90 degrees inclusive, and the longitude bounds must range between -180 to 180 degrees inclusive. Various cases include:

  • If low = high, the viewport consists of that single point.

  • If low.longitude > high.longitude, the longitude range is inverted (the viewport crosses the 180 degree longitude line).

  • If low.longitude = -180 degrees and high.longitude = 180 degrees, the viewport includes all longitudes.

  • If low.longitude = 180 degrees and high.longitude = -180 degrees, the longitude range is empty.

  • If low.latitude > high.latitude, the latitude range is empty.

Both low and high must be populated, and the represented box cannot be empty (as specified by the definitions above). An empty viewport will result in an error.

For example, this viewport fully encloses New York City:

{ “low”: { “latitude”: 40.477398, “longitude”: -74.259087 }, “high”: { “latitude”: 40.91618, “longitude”: -73.70018 } }

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
low: Option<LatLng>

Required. The low point of the viewport.

high: Option<LatLng>

Required. The high point of the viewport.

Implementations

Source

impl Viewport

pub fn new() -> Self

Creates a new default instance.

pub fn set_low<T>(self, v: T) -> Self
where T: Into<LatLng>,

Sets the value of low.

Example
use google_cloud_type::model::LatLng;
let x = Viewport::new().set_low(LatLng::default()/* use setters */);
pub fn set_or_clear_low<T>(self, v: Option<T>) -> Self
where T: Into<LatLng>,

Sets or clears the value of low.

Example
use google_cloud_type::model::LatLng;
let x = Viewport::new().set_or_clear_low(Some(LatLng::default()/* use setters */));
let x = Viewport::new().set_or_clear_low(None::<LatLng>);
pub fn set_high<T>(self, v: T) -> Self
where T: Into<LatLng>,

Sets the value of high.

Example
use google_cloud_type::model::LatLng;
let x = Viewport::new().set_high(LatLng::default()/* use setters */);
pub fn set_or_clear_high<T>(self, v: Option<T>) -> Self
where T: Into<LatLng>,

Sets or clears the value of high.

Example
use google_cloud_type::model::LatLng;
let x = Viewport::new().set_or_clear_high(Some(LatLng::default()/* use setters */));
let x = Viewport::new().set_or_clear_high(None::<LatLng>);